##################################################################################
#                       Auto-generated Metaflow stub file                        #
# MF version: 2.11.2                                                             #
# Generated on 2024-02-08T21:32:40.863419                                        #
##################################################################################

from __future__ import annotations

import typing
if typing.TYPE_CHECKING:
    import metaflow.plugins.pypi.conda_environment
    import metaflow.metaflow_environment

class CondaEnvironment(metaflow.metaflow_environment.MetaflowEnvironment, metaclass=type):
    def __init__(self, flow):
        ...
    def set_local_root(self, local_root):
        ...
    def decospecs(self):
        ...
    def validate_environment(self, echo, datastore_type):
        ...
    def init_environment(self, echo):
        ...
    def executable(self, step_name, default = None):
        ...
    def interpreter(self, step_name):
        ...
    def is_disabled(self, step):
        ...
    def pylint_config(self):
        ...
    @classmethod
    def get_client_info(cls, flow_name, metadata):
        ...
    def add_to_package(self):
        ...
    def bootstrap_commands(self, step_name, datastore_type):
        ...
    def get_environment_manifest_path(self):
        ...
    def read_from_environment_manifest(self, keys):
        ...
    def write_to_environment_manifest(self, keys, value):
        ...
    ...

class PyPIEnvironment(metaflow.plugins.pypi.conda_environment.CondaEnvironment, metaclass=type):
    ...

